From: agk@sourceware.org <agk@sourceware.org>
To: lvm-devel@redhat.com
Subject: LVM2 ./WHATS_NEW lib/metadata/mirror.c
Date: 17 Oct 2008 10:50:16 -0000 [thread overview]
Message-ID: <20081017105016.26596.qmail@sourceware.org> (raw)
CVSROOT: /cvs/lvm2
Module name: LVM2
Changes by: agk at sourceware.org 2008-10-17 10:50:15
Modified files:
. : WHATS_NEW
lib/metadata : mirror.c
Log message:
In resume_mirror_images replace activate_lv with resume_lv as workaround.
(The resume has the side-effect of resuming all of the original
mirror's sub-lvs in addition to the new 'error' target middle layer.)
Patches:
http://sourceware.org/cgi-bin/cvsweb.cgi/LVM2/WHATS_NEW.diff?cvsroot=lvm2&r1=1.975&r2=1.976
http://sourceware.org/cgi-bin/cvsweb.cgi/LVM2/lib/metadata/mirror.c.diff?cvsroot=lvm2&r1=1.77&r2=1.78
--- LVM2/WHATS_NEW 2008/10/17 00:55:46 1.975
+++ LVM2/WHATS_NEW 2008/10/17 10:50:14 1.976
@@ -1,5 +1,6 @@
Version 2.02.41 -
=====================================
+ In resume_mirror_images replace activate_lv with resume_lv as workaround.
Avoid overwriting in-use on-disk text metadata by forgetting MDA_HEADER_SIZE.
Fix snapshot monitoring library to not cancel monitoring invalid snapshot.
Generate man pages from templates and include version.
--- LVM2/lib/metadata/mirror.c 2008/09/19 04:30:02 1.77
+++ LVM2/lib/metadata/mirror.c 2008/10/17 10:50:14 1.78
@@ -598,13 +598,13 @@
log_very_verbose("Updating \"%s\" in kernel", mirrored_seg->lv->name);
/*
* Avoid having same mirror target loaded twice simultaneouly by first
* activating the removed LV which now contains an error segment.
* As it's now detached from mirrored_seg->lv we must activate it
* explicitly.
*/
- if (lv1 && !activate_lv(lv1->vg->cmd, lv1)) {
- log_error("Problem reactivating removed %s", lv1->name);
+ if (lv1 && !resume_lv(lv1->vg->cmd, lv1)) {
+ log_error("Problem resuming temporary LV, %s", lv1->name);
return 0;
}
next reply other threads:[~2008-10-17 10:50 UTC|newest]
Thread overview: 28+ messages / expand[flat|nested] mbox.gz Atom feed top
2008-10-17 10:50 agk [this message]
-- strict thread matches above, loose matches on Subject: below --
2012-03-23 16:28 LVM2 ./WHATS_NEW lib/metadata/mirror.c mbroz
2012-02-01 13:50 zkabelac
2011-10-25 13:17 jbrassow
2011-10-06 14:49 jbrassow
2011-09-14 2:45 jbrassow
2011-09-13 21:13 jbrassow
2011-09-13 14:37 jbrassow
2011-09-13 13:59 jbrassow
2011-09-01 19:22 jbrassow
2011-06-17 14:27 zkabelac
2010-08-16 18:02 jbrassow
2010-07-13 22:24 jbrassow
2010-07-13 21:48 jbrassow
2010-07-09 15:08 jbrassow
2010-06-28 14:19 jbrassow
2010-06-21 16:12 jbrassow
2010-04-27 15:26 jbrassow
2010-04-27 14:57 jbrassow
2009-12-09 19:53 mbroz
2009-12-09 18:09 mbroz
2009-04-10 9:53 mbroz
2008-09-18 19:09 agk
2008-06-13 12:15 meyering
2008-02-22 13:28 agk
2007-11-22 13:57 agk
2006-11-30 17:52 agk
2006-11-10 19:35 agk
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20081017105016.26596.qmail@sourceware.org \
--to=agk@sourceware.org \
--cc=lvm-devel@redhat.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -598,13 +598,13 @@
log_very_verbose("Updating \"%s\" in kernel", mirrored_seg->lv->name);
/*
- * Avoid having same mirror target loaded twice simultaneouly by first
- * activating the removed LV which now contains an error segment.
- * As it's now detached from mirrored_seg->lv we must activate it
+ * Avoid having same mirror target loaded twice simultaneously by first
+ * resuming the removed LV which now contains an error segment.
+ * As it's now detached from mirrored_seg->lv we must resume it
* explicitly.
*/
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.